==> dataone.onedrive-3.0.4-py3-none-any.whl: d1_onedrive/impl/clients/query_engine_description.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Cache and manipulate a queryEngineDescription
"""

import logging

# Set up logger for this module.
log = logging.getLogger(__name__)
# Set specific logging level for this module if specified.
try:
  log.setLevel(logging.getLevelName(logging.ONEDRIVE_MODULES[__name__]))
except (KeyError, AttributeError):
  pass

# class QueryEngineDescription(object):
#   def __init__(self):
#     self.doc = None
#
#   def download(self, query_url):
#     i = urllib.urlopen(query_url)
#     self.read(i)
#
#   def load(self, xml_path):
#     i = open(xml_path, 'rb').read()
#     self.read(i)
#
#   def read(self, xml_file):
#     self.doc = dataoneTypes.CreateFromDocument(xml_file)
#
#   def assert_is_initialized(self):
#     assert self.doc is not None
#
#   def get_query_engine_version(self):
#     return self.doc.queryEngineVersion
#

==> dataone.onedrive-3.3.0-py3-none-any.whl: d1_onedrive/impl/clients/query_engine_description.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Cache and manipulate a queryEngineDescription."""

import logging

# Set up logger for this module.
log = logging.getLogger(__name__)
# Set specific logging level for this module if specified.
try:
    log.setLevel(logging.getLevelName(logging.ONEDRIVE_MODULES[__name__]))
except (KeyError, AttributeError):
    pass

# class QueryEngineDescription(object):
#   def __init__(self):
#     self.doc = None
#
#   def download(self, query_url):
#     i = urllib.urlopen(query_url)
#     self.read(i)
#
#   def load(self, xml_path):
#     i = open(xml_path, 'rb').read()
#     self.read(i)
#
#   def read(self, xml_file):
#     self.doc = dataoneTypes.CreateFromDocument(xml_file)
#
#   def assert_is_initialized(self):
#     assert self.doc is not None
#
#   def get_query_engine_version(self):
#     return self.doc.queryEngineVersion
#
